Credits
=======
Authors
-------
- Artur Barseghyan

Contributors
------------
- malthe: Reported and proposed a fix for an issue with URLs with a port not
  handled correctly. Reported and proposed a fix for speeding up the search
  in tld names by replacing the list with set.
- `Todd Wolfson
  <https://github.com/barseghyanartur/tld/commits/master?author=twolfson>`_
  for exposing the TLD initialization as `get_tld_names`.
- `mperice
  <https://github.com/barseghyanartur/tld/commits/master?author=mperice>`_
  for minor fixes.
- `Jonathan Stoppani
  <https://github.com/barseghyanartur/tld/commits/master?author=GaretJax>`_
  for minor fixes.
- `Michael Kearns
  <https://github.com/barseghyanartur/tld/commits?author=mobiuscog>`_ for
  adding base path override for local .dat file.

Bug reporters
~~~~~~~~~~~~~
The following people contributed to the project by reporting bugs.

- Yoni Stoffman: Reported an issue with Python 3 support on Windows (encoding
  problem).
- mickey06: Reporting an issue with capitalised URLs.
